@@ -44,12 +44,12 @@ class ProcessExecutor
     public function execute($command, &$output = null, $cwd = null)
     {
         if ($this->io && $this->io->isDebug()) {
-            $safeCommand = preg_replace_callback('{(://)(?P<user>[^:/\s]+):(?P<password>[^@\s/]+)}i', function ($m) {
+            $safeCommand = preg_replace_callback('{://(?P<user>[^:/\s]+):(?P<password>[^@\s/]+)@}i', function ($m) {
                 if (preg_match('{^[a-f0-9]{12,}$}', $m['user'])) {
-                    return '://***:***';
+                    return '://***:***@';
                 }
 
-                return '://'.$m['user'].':***';
+                return '://'.$m['user'].':***@';
             }, $command);
             $this->io->writeError('Executing command ('.($cwd ?: 'CWD').'): '.$safeCommand);
         }
@@ -99,7 +99,17 @@ class ProcessExecutor
             return;
         }
 
-        echo $buffer;
+        if (null === $this->io) {
+            echo $buffer;
+
+            return;
+        }
+
+        if (Process::ERR === $type) {
+            $this->io->writeError($buffer, false);
+        } else {
+            $this->io->write($buffer, false);
+        }
     }
 
     public static function getTimeout()
