@@ -142,6 +142,44 @@ JSON;
         return $driver;
     }
 
+        /**
+         * @dataProvider getInitializeUrls
+         */
+        public function testInitializePublicProjectAsAnonymous($url, $apiUrl)
+        {
+            // @link http://doc.gitlab.com/ce/api/projects.html#get-single-project
+            $projectData = <<<JSON
+{
+    "id": 17,
+    "default_branch": "mymaster",
+    "http_url_to_repo": "https://gitlab.com/mygroup/myproject.git",
+    "ssh_url_to_repo": "git@gitlab.com:mygroup/myproject.git",
+    "last_activity_at": "2014-12-01T09:17:51.000+01:00",
+    "name": "My Project",
+    "name_with_namespace": "My Group / My Project",
+    "path": "myproject",
+    "path_with_namespace": "mygroup/myproject",
+    "web_url": "https://gitlab.com/mygroup/myproject"
+}
+JSON;
+
+        $this->remoteFilesystem
+            ->getContents('gitlab.com', $apiUrl, false, array())
+            ->willReturn($projectData)
+            ->shouldBeCalledTimes(1)
+        ;
+
+        $driver = new GitLabDriver(array('url' => $url), $this->io->reveal(), $this->config, $this->process->reveal(), $this->remoteFilesystem->reveal());
+        $driver->initialize();
+
+        $this->assertEquals($apiUrl, $driver->getApiUrl(), 'API URL is derived from the repository URL');
+        $this->assertEquals('mymaster', $driver->getRootIdentifier(), 'Root identifier is the default branch in GitLab');
+        $this->assertEquals('https://gitlab.com/mygroup/myproject.git', $driver->getRepositoryUrl(), 'The repository URL is the SSH one by default');
+        $this->assertEquals('https://gitlab.com/mygroup/myproject', $driver->getUrl());
+
+        return $driver;
+    }
+
     public function testGetDist()
     {
         $driver = $this->testInitialize('https://gitlab.com/mygroup/myproject', 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject');
@@ -236,24 +274,34 @@ JSON;
         $apiUrl = 'https://gitlab.com/api/v4/projects/mygroup%2Fmyproject/repository/branches?per_page=100';
 
         // @link http://doc.gitlab.com/ce/api/repositories.html#list-project-repository-branches
-        $branchData = <<<JSON
-[
-    {
-       "name": "mymaster",
-        "commit": {
-            "id": "97eda36b5c1dd953a3792865c222d4e85e5f302e",
-            "committed_date": "2013-01-03T21:04:07.000+01:00"
+        $branchData = array(
+            array(
+               "name" => "mymaster",
+                "commit" => array(
+                    "id" => "97eda36b5c1dd953a3792865c222d4e85e5f302e",
+                    "committed_date" => "2013-01-03T21:04:07.000+01:00"
+                )
+            ),
+            array(
+                "name" => "staging",
+                "commit" => array(
+                    "id" => "502cffe49f136443f2059803f2e7192d1ac066cd",
+                    "committed_date" => "2013-03-09T16:35:23.000+01:00"
+                )
+            ),
+        );
+
+        for ($i = 0; $i < 98; $i++) {
+            $branchData[] = array(
+                "name" => "stagingdupe",
+                "commit" => array(
+                    "id" => "502cffe49f136443f2059803f2e7192d1ac066cd",
+                    "committed_date" => "2013-03-09T16:35:23.000+01:00"
+                )
+            );
         }
-    },
-    {
-        "name": "staging",
-        "commit": {
-            "id": "502cffe49f136443f2059803f2e7192d1ac066cd",
-            "committed_date": "2013-03-09T16:35:23.000+01:00"
-        }
-    }
-]
-JSON;
+
+        $branchData = json_encode($branchData);
 
         $this->remoteFilesystem
             ->getContents('gitlab.com', $apiUrl, false, array())
@@ -279,6 +327,7 @@ JSON;
         $expected = array(
             'mymaster' => '97eda36b5c1dd953a3792865c222d4e85e5f302e',
             'staging' => '502cffe49f136443f2059803f2e7192d1ac066cd',
+            'stagingdupe' => '502cffe49f136443f2059803f2e7192d1ac066cd',
         );
 
         $this->assertEquals($expected, $driver->getBranches());
